#
# spec file for package antimicrox
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           antimicrox
Version:        3.2.0
Release:        bp154.1.79
Summary:        Graphical program used to map keyboard keys and mouse controls to a game-pad
License:        GPL-3.0-or-later
Group:          Hardware/Joystick
URL:            https://github.com/AntiMicroX/antimicroX
Source0:        https://github.com/AntiMicroX/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE remove_datetime_aboutdialog.patch -- avoid unneccessary rebuilds
Patch0:         remove_datetime_aboutdialog.patch
# PATCH-FIX-OPENSUSE fix_xcb_linker.patch -- fix linking xcb
Patch1:         fix_xcb_linker.patch
BuildRequires:  cmake >= 3.12
BuildRequires:  desktop-file-utils
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  itstool
BuildRequires:  libqt5-qttools-devel
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xtst)

%description
Antimicrox is a graphical program used to map keyboard keys and mouse
controls to a gamepad. This program is useful for playing PC games using
a gamepad that do not have any form of built-in gamepad support.
However, you can use this program to control any desktop application with
a gamepad; on Linux, this means that your system has to be running an
X environment in order to run this program.

This application is continuation of project called AntiMicro,
which was later abandoned and revived by juliagoda.

%prep
%setup -q
%autopatch -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%find_lang %{name} --with-qt

# remove redundant changelog
rm %{buildroot}%{_datadir}/%{name}/CHANGELOG.md
rm %{buildroot}%{_datadir}/doc/%{name}/CHANGELOG.md

%fdupes %{buildroot}%{_datadir}
%suse_update_desktop_file -r io.github.antimicrox.%{name} System HardwareSettings

%files
%license LICENSE
%doc CHANGELOG.md README.md ProfileTips.md
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/io.github.antimicrox.%{name}.desktop
%{_datadir}/metainfo/io.github.antimicrox.%{name}.appdata.xml
%{_datadir}/mime/packages/io.github.antimicrox.%{name}.xml
%{_datadir}/icons/hicolor/*/apps/*
%dir %{_datadir}/icons/breeze
%dir %{_datadir}/icons/breeze/48x48
%{_datadir}/icons/breeze/48x48/apps*
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_udevrulesdir}/60-%{name}-uinput.rules

%changelog
* Mon Nov  1 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.2.0
  - Prepare installer for Windows
  - Handle segfaults and other crashes in code
  - Create config for debug builds
  - Allow unhiding app window when second instance of AntiMicroX is launched
  - Typo in udev rule name: 60-antimicrox-uinput.rules instead
    60-antimcrox-uinput.rules
  - Move gui-related files to separate directory
  - Logging system improvements
  - Some additional logs and notes
  - Fix compile warnings
  - Set homepage url for packages
  - Create config for debug build
  - Cmake cleanup
- Rebase remove_datetime_aboutdialog.patch
* Sat Sep 11 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1.7
  - Wayland support for keyboard emulation rocket
  - Load save dialogue window won't show saved configs = can't
    open saves
  - Segmentation Fault when change profile from command line
  - Include Appstream information into AppImage Build
  - fix: Remove warning "QLocalSocket::waitForDisconnected()
    is not allow…
  - Crash-related fixes linked with memory management
  - refactor: Improve log showing gamepad name
  - refactor: Refactor executing commands
  - Allow regular users using uinput
  - feat: switch from xtest to uinput when wayland is detected
- Update BuildRequires: cmake >= 3.12 is needed
- Fix some rpmlint warnings
* Sat Aug 28 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1.6
  - Saving logs into file doesn't work properly
  - Doesn't save my configurations/Wont auto load
  - Refactor logging system
  - Add new logs associated with loading profile files
  - Refactor arguments parsing
  - docs: Add information about commandline for flatpak packages
  - Added openSUSE instruction
* Sun Mar 14 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1.5
  - Migrate DEB packages to antimicrox #87
  - Integrate builds marking with docs cmake and CI #143
  - Allow cleaner marking package builds #143 (mirabilos)
  - fix appdata formatting #142 (mirabilos)
  - apply lintian-provided spelling fixes #141 (mirabilos)
  - fix the manpage (hyphen as minus sign) #140 (mirabilos)
  - fix: change deb arch prefix for building AppImage #135 (pktiuk)
- Rebase remove_datetime_aboutdialog.patch
- Drop devel package
* Fri Jan 15 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1.4
  - Remove qglobalshortcuts #106
  - File cleanup #104
  - Cmakefile fixes #102
  - Add dark tray icon #66
  - Icons overhaul #61
  - Automate generating changelogs #10
  - Clear shortcut not working #116
  - Assigning Text Entry to button doesn't assign proper string. #79
  - The uninstallation leaves several folders and files behind
    (cmake) #68
  - Remove antilib shared object because it's not really shared! #98
  - feat: improve mime type definition #132 (Janfel)
  - docs: update building and installation instructions #129 (pktiuk)
  - feat: antimicro config migration #120 (gombosg)
- Rebase fix_xcb_linker.patch
- Clean up because of remove of antilib #98
  - Drop antilib-lib package
  - Drop antimicrox.rpmlintrc
* Sat Dec 12 2020 Carsten Ziepke <kieltux@gmail.com>
- Fix rpmlintrc: Instead setBadness now addFilter is used.
  For Factory submissions setBadness can not be used.
* Sat Dec 12 2020 Carsten Ziepke <kieltux@gmail.com>
- Fix BuildRequires: cmake >= 3.6 is needed
* Sat Nov 28 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1.3
  - ARM build failure #80
  - AntiMicroX system tray icon not appearing in flatpak
    package #58
  - Icons in tray menu only showing up as "X" #56
  - Outdated information in the "Credits" tab in the "About"
    window #67
  - Consistent style of code #25
  - Icons overhaul #73 (pktiuk)
  - Fix: Use system icons in common cases to avoid incompatibility
    issues #62 (pktiuk)
  - General cleanup of repository #18 (pktiuk)
- Addded full source URL in spec file
* Wed Nov 11 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1.2
  - Right click - Turbo and Clear not working properly #7
  - Wrong order for setting sets #6
* Sun Sep 13 2020 Carsten Ziepke <kieltux@gmail.com>
- Initial package version in OBS
